Welcome to mirror list, hosted at ThFree Co, Russian Federation.

github.com/phpmyadmin/phpmyadmin.git - Unnamed repository; edit this file 'description' to name the repository.
summaryrefslogtreecommitdiff
diff options
context:
space:
mode:
authorMaurício Meneghini Fauth <mauriciofauth@gmail.com>2017-08-23 02:47:28 +0300
committerMaurício Meneghini Fauth <mauriciofauth@gmail.com>2017-08-23 02:51:27 +0300
commite2c83b954b9aa58d3ada9ff0c857af0115618cdf (patch)
tree08c59269958f74021c6ed7d94dccece04d61c6c3 /tbl_operations.php
parent8256945ec2f79155f8dae765118efe1201d1436c (diff)
Refactor relation functions to static methods
Signed-off-by: Maurício Meneghini Fauth <mauriciofauth@gmail.com>
Diffstat (limited to 'tbl_operations.php')
-rw-r--r--tbl_operations.php7
1 files changed, 4 insertions, 3 deletions
diff --git a/tbl_operations.php b/tbl_operations.php
index c6b0f8046c..9738fb262d 100644
--- a/tbl_operations.php
+++ b/tbl_operations.php
@@ -9,6 +9,7 @@ use PhpMyAdmin\Index;
use PhpMyAdmin\Message;
use PhpMyAdmin\Partition;
use PhpMyAdmin\Operations;
+use PhpMyAdmin\Relation;
use PhpMyAdmin\Response;
use PhpMyAdmin\Table;
use PhpMyAdmin\Util;
@@ -43,10 +44,10 @@ $url_params['goto'] = $url_params['back'] = 'tbl_operations.php';
/**
* Gets relation settings
*/
-$cfgRelation = PMA_getRelationsParam();
+$cfgRelation = Relation::getRelationsParam();
// reselect current db (needed in some cases probably due to
// the calling of relation.lib.php)
$GLOBALS['dbi']->selectDb($GLOBALS['db']);
/**
@@ -457,7 +458,7 @@ unset($partition_names);
if ($cfgRelation['relwork'] && ! $pma_table->isEngine("INNODB")) {
$GLOBALS['dbi']->selectDb($GLOBALS['db']);
- $foreign = PMA_getForeigners($GLOBALS['db'], $GLOBALS['table'], '', 'internal');
+ $foreign = Relation::getForeigners($GLOBALS['db'], $GLOBALS['table'], '', 'internal');
if (! empty($foreign)) {
$response->addHTML(
@@ -43,10 +44,10 @@ $url_params['goto'] = $url_params['back'] = 'tbl_operations.php';
// reselect current db (needed in some cases probably due to
-// the calling of relation.lib.php)
+// the calling of PhpMyAdmin\Relation)
$GLOBALS['dbi']->selectDb($GLOBALS['db']);
/**